summaryrefslogtreecommitdiff
path: root/scripts
diff options
context:
space:
mode:
authorGeorge Fraser <george@fivetran.com>2018-12-14 16:55:15 -0800
committerGeorge Fraser <george@fivetran.com>2018-12-14 16:55:25 -0800
commit794182af3cdaedebd54ddafc8daa94cf026704f7 (patch)
treef29dcce1890ead17b9b9e058bf91aa337f4b2924 /scripts
parentecd79266956a6761ead9defe00db4fb90d361d32 (diff)
downloadjava-language-server-794182af3cdaedebd54ddafc8daa94cf026704f7.zip
Update modules for java 11
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/build.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/build.sh b/scripts/build.sh
index 865f1df..ae23d98 100755
--- a/scripts/build.sh
+++ b/scripts/build.sh
@@ -4,8 +4,8 @@
# You will need java, maven, vsce, and visual studio code to run this script
set -e
-# Needed if you have a java version other than 10 as default
-JAVA_HOME=$(/usr/libexec/java_home -v 10)
+# Needed if you have a java version other than 11 as default
+JAVA_HOME=$(/usr/libexec/java_home -v 11)
# Needed once
npm install